/*
 * Copyright 2018 Daniel Gultsch
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package im.quicksy.server.configuration;

public class DatabaseConfigurationBundle {

    private DatabaseConfiguration ejabberd;
    private DatabaseConfiguration quicksy;

    private DatabaseConfigurationBundle() {}

    public DatabaseConfiguration getEjabberdConfiguration() {
        return ejabberd;
    }

    public DatabaseConfiguration getQuicksyConfiguration() {
        return quicksy;
    }

    public static class Builder {

        private final DatabaseConfigurationBundle bundle = new DatabaseConfigurationBundle();

        public Builder setEjabberdConfiguration(DatabaseConfiguration configuration) {
            bundle.ejabberd = configuration;
            return this;
        }

        public Builder setQuicksyConfiguration(DatabaseConfiguration configuration) {
            bundle.quicksy = configuration;
            return this;
        }

        public DatabaseConfigurationBundle build() {
            return bundle;
        }
    }
}
